import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { screen, cleanup, render, fireEvent } from "@testing-library/react";
import "@testing-library/jest-dom/extend-expect";
import RightClickMenu from "./RightClickMenu";
describe("RightClickMenu", () => {
    let element;
    // initializing before each
    beforeEach(() => {
        // clean up
        cleanup();
        // render component
        const page = (_jsxs("div", Object.assign({ className: "test", "data-testid": "test" }, { children: [_jsx(RightClickMenu, { rightClickTargets: [
                        { className: "test0", menuList: ["hello"] },
                        {
                            className: "test1",
                            menuList: [
                                _jsx("p", Object.assign({ className: "description" }, { children: "description" }), void 0),
                                _jsx("button", Object.assign({ className: "btn" }, { children: "click" }), void 0),
                            ],
                        },
                    ] }, void 0), _jsx("div", { className: "test0", "data-testid": "test0" }, void 0), _jsx("div", { className: "test1", "data-testid": "test1" }, void 0)] }), void 0));
        render(page);
        element = screen.getByTestId("RightClickMenu");
    });
    it("should be in the documentation", () => {
        expect(element).toBeInTheDocument();
        expect(element.tagName).toBe("UL");
    });
    it("shouldn't have the display className or not be visible", () => {
        expect(element.className).not.toMatch("display");
    });
    it("should show menu on page on the right click on targetClass", () => {
        const testElement = screen.getByTestId("test0");
        expect(testElement).toBeInTheDocument();
        if (testElement) {
            fireEvent.contextMenu(testElement);
        }
        console.log(testElement);
        expect(element.className).toMatch("display");
    });
    it("should append correct children to menu on contextmenu event on each element", () => {
        var _a, _b;
        const test0 = screen.getByTestId("test0");
        if (test0)
            fireEvent.contextMenu(test0);
        expect(element === null || element === void 0 ? void 0 : element.children.length).toBe(1);
        expect(element === null || element === void 0 ? void 0 : element.textContent).toMatch("hello");
        const test1 = screen.getByTestId("test1");
        if (test1)
            fireEvent.contextMenu(test1);
        expect(element === null || element === void 0 ? void 0 : element.children.length).toBe(2);
        expect((_a = element === null || element === void 0 ? void 0 : element.querySelector("button")) === null || _a === void 0 ? void 0 : _a.textContent).toMatch("click");
        expect((_b = element === null || element === void 0 ? void 0 : element.querySelector("button")) === null || _b === void 0 ? void 0 : _b.className).toMatch("btn");
        expect(element.querySelector(".description")).toBeInTheDocument();
    });
});
//# sourceMappingURL=RightClickMenu.test.js.map